@@ -1,7 +1,6 @@
 /*
-**  pth_cancel.c -- Pth thread cancellation
-**
-**  Copyright (c) 1999 Ralf S. Engelschall <rse@engelschall.com>
+**  GNU Pth - The GNU Portable Threads
+**  Copyright (c) 1999-2000 Ralf S. Engelschall <rse@engelschall.com>
 **
 **  This file is part of GNU Pth, a non-preemptive thread scheduling
 **  library which can be found at http://www.gnu.org/software/pth/.
@@ -20,6 +19,8 @@
 **  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
+**
+**  pth_cancel.c: Pth thread cancellation
 */
                              /* ``Study it forever and you'll still wonder.
                                   Fly it once and you'll know.''
@@ -39,7 +40,7 @@ void pth_cancel_state(int newstate, int *oldstate)
 /* enter a cancellation point */
 void pth_cancel_point(void)
 {
-    if (   pth_current->cancelreq == TRUE 
+    if (   pth_current->cancelreq == TRUE
         && pth_current->cancelstate & PTH_CANCEL_ENABLE) {
         /* avoid looping if cleanup handlers contain cancellation points */
         pth_current->cancelreq = FALSE;
@@ -69,7 +70,7 @@ int pth_cancel(pth_t thread)
     thread->cancelreq = TRUE;
 
     /* when cancellation is enabled in async mode we cancel the thread immediately */
-    if (   thread->cancelstate & PTH_CANCEL_ENABLE 
+    if (   thread->cancelstate & PTH_CANCEL_ENABLE
         && thread->cancelstate & PTH_CANCEL_ASYNCHRONOUS) {
 
         /* remove thread from its queue */
@@ -85,16 +86,8 @@ int pth_cancel(pth_t thread)
             return_errno(FALSE, ESRCH);
         pth_pqueue_delete(q, thread);
 
-        /* run the cleanup handlers */
-        if (thread->cleanups != NULL)
-            pth_cleanup_popall(thread, TRUE);
-
-        /* run the specific data destructors */
-        if (thread->data_value != NULL)
-            pth_key_destroydata(thread);
-
-        /* release still acquired mutex variables */
-        pth_mutex_releaseall(thread);
+        /* execute cleanups */
+        pth_thread_cleanup(thread);
 
         /* and now either kick it out or move it to dead queue */
         if (!thread->joinable) {
