@@ -52,11 +52,11 @@
 
 #endif /* cpp */
 
-intern void pth_debug(char *file, int line, char *fmt, ...)
+intern void pth_debug(const char *file, int line, const char *fmt, ...)
 {
     va_list ap;
     static char str[1024];
-    int n;
+    size_t n;
 
     errno_shield {
         va_start(ap, fmt);
@@ -92,7 +92,7 @@ intern void pth_dumpstate(FILE *fp)
     return;
 }
 
-intern void pth_dumpqueue(FILE *fp, char *qn, pth_pqueue_t *q)
+intern void pth_dumpqueue(FILE *fp, const char *qn, pth_pqueue_t *q)
 {
     pth_t t;
     int n;
